function [ rho_molar ] = Density_EtOH_high_pressure( T, P )
% Calculation of the molar density  of ethanol depending on pressure and temperature
% equation:  volume translated Peng-Robinson EOS (c = 4.275*10^-6 m3/mol)
% input: temperatur [K], pressure [Pa]
% output: molar density [mol/m3]
% range of validity: P = 8-20 MPa und T = 270-350 K
% AARD: 0.29%, MAPE: 2.06% (104 data points)

R = 8.3144621;   

% ethanol properties
Tc = 513.92; % K
Pc = 6.148e6; % Pa
vc = 0.167e-3; % m3/mol
omega = 0.649; 
M = 46.069; % g/mol

kappa = 0.37464 + 1.54226*omega - 0.26992*omega^2;
alpha = (1 + kappa * ( 1 - (T/Tc).^0.5 )).^2;

a = 0.45724 * R^2 * Tc^2 * alpha / Pc;
b = 0.07780 * R * Tc / Pc;
c = -4.275e-6; %m3/mol

A =  P *R^-2 * a.* (T.^(-2));
B = b * P * R^(-1) * T.^(-1);

poly = [1 -(1-B) (A-3*B^2 -2*B) -(A*B-B^2-B^3)];
Z_all = roots(poly);

for j=1:size(Z_all,1)  
    if isreal(Z_all(j))
        Z = Z_all(j);
    end   
end

v = Z*R*T/P + c; % m3/mol
rho_molar = 1/v; % mol/m3

end

