function [ D21 ] = Diffusion_coefficient_EtOH_in_CO2( T, P )
% Calculation of the diffusion coefficient of ethanol in supercritical CO2 depending on temperature and pressure
% equation: correlation of Magalhaes et al. 2013 
% input: temperature [K], pressure [Pa]
% output: binary diffusion coefficient [m2/s] at infinite dilution
% 1: scCO2     2: EtOH

% component properties
Tc1 =  304.12; % K        
vc1 = 0.09407e-3; % m3/mol
M1 = 44.010; % g/mol
M2 = 46.069; % g/mol

rho1 = M1*Density_scCO2( T, P )/1000; % kg/m^3
 
a7 = -9.43368e-14; % in m^5/kg/K/s
b7 = 1.29638e-10;  % in m^2/K/s


D21 = T*(a7*rho1 + b7);


end