function [ D_L ] = Dispersion_coefficient( v, R, D_F, tau_F, Sc, Re )
 % Calculation of axial/longitudinal dispersion coefficient depending on velocity
 % according to the paper of Delgado 2007
 % equations for the "liquid flow" are used, since the results for supercritical CO2 are shown in the diagram for "liquid flow"
 
%Calculation Pe_m 
Pe_m = v*2*R/D_F;
D_m_line = D_F/tau_F;
Pe_m_line = v*2*R/D_m_line;

if  Pe_m < 0.1
    D_L = D_m_line; 
end 

if  Pe_m > 0.1 && Pe_m < 4
    D_L = D_m_line*Pe_m_line/(0.8/Pe_m_line + 0.4);
end 

if  Pe_m > 4 && Re < 10
    D_L = D_m_line*Pe_m_line/((18*Pe_m_line^-1.2 + 2.35*Sc^-0.38)^(1/2));
end

if Re > 10 && Pe_m < 1000000
    D_L = D_m_line*Pe_m_line/(25*Sc^1.14/Pe_m_line + 0.5);
end 

if Pe_m > 1000000
    D_L = D_m_line*Pe_m_line/2;
end 

end 