function [ ACFS, b ] = FVM_function( v_bed, D_L, source, S, dz )
%% completeFlux v 1.0.0, Patricio Farrell, 2017
% This work is licensed under a Creative Commons 
% Attribution-NonCommercial-ShareAlike 4.0 International License.

% When using this software, cite it with
%
%   P. Farrell, completeFlux v. 1.0.0, 2017
%
% as well as the corresponding paper
%
%   P. Farrell, A. Linke. Uniform Second Order Convergence of a Complete 
%   Flux Scheme on Unstructured 1D Grids for a Singularly Perturbed 
%   Advection-Diffusion Equation and Some Multidimensional Extensions, 
%   Journal of Scientific Computing, 72-1 (2017), pp. 373-395, 
%   DOI: 10.1007/s10915-017-0361-7
%
% The code solves the problem below via a finite volume method, namely the
% complete flux scheme. It assumes constant diffusion and variable
% advection and source term. The latter two functions will be approximated
% by piecewise constant functions.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Complete Flux Scheme 
% Consider on the domain = [0,1] the convection-diffusion problem
%
%   (-Dc' + vc)' = s
%   c(0) = cLeft 
%   c(1) = cRight
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% %% Format plots
% fontname = 'helvetica';%'palatino';
% set(0,'defaultaxesfontname',fontname);
% set(0,'defaulttextfontname',fontname);
% set(0,'defaultaxesfontsize',24);
% set(0,'defaulttextfontsize',20);


%% Setting up parameters

% Define domain in 1D and parameters
domainLeft  = 0;%-0.5*dz;
domainRight = (S-0.5)*dz;
D =  D_L;                     % constant diffusion
v =  transpose(v_bed);  
% for i=2:S+1
% s(i)= source(i-1);
% end 
s=transpose(source); 
%vfunc = @(x) ones(size(x));    % variable advection


% Set up number of (total) grid points
numberGridPoints = S; % Stufenanzahl plus Punkte fr Randbedingungen
%numberInteriorGridPoints = S;


% % Set grid type to 'random' or 'uniform'
% gridType = 'uniform'; %'uniform'; %'random';%'hRandom'; nRandom
% 
% % Use more points in the region of the boundary layer (1 == 'ON')
% % numberGridPoints will be adjusted accordingly
% morePoints = 0; 
% resolutionStep = 0.01;
% resolveFromHere = 0.9;
% resolveToHere = 1;

%% Set up grids and Voronoi boxes

% % gridSize is the difference between grid points x_{j+1} - x_j
% 
% [gridWithoutBoundary, boxes, gridSize, boxSize] = computeGrids(numberGridPoints,domainLeft,domainRight,gridType,morePoints,resolutionStep,resolveFromHere,resolveToHere);
% 
% % Reset numberGridPoints if 'more points' or gridType = 'hRandom' was used
% [~, numberInteriorGridPoints] = size(gridWithoutBoundary);

% Grid and exact solution on the domain including end points
gridWholeDomain = linspace(domainLeft+0.5*dz, domainRight, numberGridPoints);
%gridWholeDomain (1) = domainLeft;%-10e20;
gridSize = diff(gridWholeDomain);
% Set up Voronoi boxes
% boxes = 0.5*(interiorGrid + gridShiftedToRight);
% boxes(end+1) = 0.5*(interiorGrid(end) + domainRight); 
boxes(1)= 0;
for i=2:S
    boxes (i) = boxes(i-1)+dz; 
end
boxes(S+1)= domainRight; 
boxSize = diff(boxes);

% gridWholeDomain = [domainLeft gridWithoutBoundary domainRight];

% % Fine grid for plotting purposes
% gridFine = linspace(domainLeft,domainRight, 300);

%% Define right-hand side and set up exact solution
% Exact solution  for s(x) = D*pi^2*k^2*sin(k*pi*x) + pi*k*v*cos(k*pi*x) (see Mathematica script)
% c(0) = 0 and c(1) = 0
%k=1;
%s = @(x) D*pi^2*k^2*sin(k*pi*x) + pi*k*v*cos(k*pi*x);
%source = 'sine';
%exactSolution = exact(gridWholeDomain, v, D, k, source);
%exactSolutionFine = exact(gridFine, v, D, k, source);

%% Print setup to screen

% printSetup(cLeft,cRight,s,gridType);


%% Complete Flux Scheme 
% We approximate the flux with the complete flux scheme. 

% fprintf('\nComplete Flux Scheme for the flux approximation\n')
% fprintf('----------------------------------------------------------\n')

%% Solve the linear system
% We set up the linear system and solve it.
[~, ACFS, ~, b] = SolveWithCFSNeumann(D, v, s,domainLeft, domainRight,gridWholeDomain, gridSize, boxSize, numberGridPoints, boxes);
%[cCFS, A, cn, b] = SolveWithCFSNeumann(D, v, s, cLeft, cRight,domainLeft, domainRight,gridWholeDomain, gridSize, boxSize, numberInteriorGridPoints, boxes);
%[cCFS, ACFS, ~]=SolveWithCFS(D, v, s, cLeft, cRight,domainLeft, domainRight,gridWholeDomain, gridSize, boxSize, numberInteriorGridPoints, boxes);
 
%% Compute errors
% Compute Loo, L2 and H1 errors and print them to screen

%printErrors(exactSolution, [cLeft cCFS' cRight], gridSize, boxSize);

%% Visualisation
 
%plotOneShot(gridWholeDomain, exactSolution, gridFine, exactSolutionFine, [cLeft cCFS' cRight], 'complete flux scheme')

end
