function [eta] = Viscosity_EtOH( T, P )
% Calculation of the ethanol viscosity [Pa*s] depending on pressure P and temperature T
% equation: correlation of Cano-Gomez et al 2015 
% additonal functions: viscosity at T, P = 1 atm and density at T, P = 1 atm as well as sowie at T,P
% additional equation: correlation for eta0 from Gonalves 2010
% input: temperature [K], pressure [Pa]
% output: viscosity [Pa*s]
% range of validity: P: 9-20 MPa, T: 298.15 - 353.15 K
% AARD: 1.22 %, MAPE: 2.98 % (19 data points)

A = 4.872; % fitting parameter fitted to experimental data

rho_molar = Density_EtOH_high_pressure( T, P ); % mol/m3
rho_molar_0 = Density_EtOH_ambient_pressure( T ); %mol/m3

% correlation 2 
a = 6.12e-4;
b = 2961.8;
c = 97.3;
eta0 = a * exp(b/(T+c)) * 10^-3; % [Pa s]

eta = eta0 * (rho_molar / rho_molar_0)^A;

end