function [ y2_max ] = y_EtOH_max_G_phase( T )
% Calculation of the maximum ethanol concentration of the gas phase staying in single gas phase for 1 atm < P < drying pressure depending on temperature 
% Flash calculation based on fitted parameter of the PR EOS using MR2 (two asymmetric parameter: k12=0.0488, k21=0.099, l12=l21=0.0527)
% 
k12 = 0.0488;
k21 = 0.0990; 
l12 = 0.0527;
l21 = 0.0527;

% estimation of the critical pressure using a polynom (fitted to experimental data),
% for the flash
P_max_approx = (0.12622066 * T - 31.37954573); % MPa
P1 = [0.1:0.01:P_max_approx+0.2]'*1e6; 

% calculation of the gas phase composition as f(P)
x1_cal = 0.05;
y1_cal = 0.95;
for i=1:length(P1)
    z1 = (x1_cal(i)+y1_cal(i))/2;
    P = P1(i);
    input = [T,P,z1,k12,k21,l12, l21];
    [x1_cal1, y1_cal1] = flash_PR_MR2(input);
    x1_cal = [x1_cal; x1_cal1];
    y1_cal = [y1_cal; y1_cal1];
end
x1_cal(1) = [];
y1_cal(1) = [];

y2_cal = 1 - y1_cal;

y2_max = min(y2_cal);
end

